.. _faqs:

FAQ
===

Below you can find answers to commonly asked questions as well as how to cite *pytools*.

Commonly asked questions
------------------------

If you don't see your answer below you could also try posting
on `stackoverflow <https://stackoverflow.com/>`_.

1. **What if I find a bug or have an idea for a new feature?**

    For bug reports or feature requests please use our
    `GitHub issue tracker <https://github.com/BCG-Gamma/pytools/issues>`_.
    For any other enquiries please feel free to contact us at FacetTeam@bcg.com.

2. **How can I contribute?**

    We welcome contributors! If you have minor changes in mind that would like to
    contribute, please feel free to create a pull request and be sure to follow the
    developer guidelines. For large or extensive changes please feel free to open an
    issue, or reach out to us at FacetTeam@bcg.com to discuss.

Citation
--------
If you use *pytools* in your work please cite us as follows:

Bibtex entry:

.. parsed-literal::
     @manual{
     title={pytools},
     author={Pytools Team at BCG Gamma},
     year={2021},
     note={Python package version |version|}
     }
